==> haskell-data-clist-0.2-69-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-clist
version:              0.2
visibility:           public
id:                   data-clist-0.2-3h05bg3ef6q4JSfIXYvR3C
key:                  data-clist-0.2-3h05bg3ef6q4JSfIXYvR3C
license:              BSD-3-Clause
maintainer:
    Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>

author:               John Van Enk <vanenkj@gmail.com>
stability:            experimental
homepage:             https://github.com/sw17ch/data-clist
synopsis:             Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.

category:             Data Structures
abi:                  8f9bed5e47a2d75822bad3dca414d6af
exposed:              True
exposed-modules:      Data.CircularList Data.CircularList.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-clist-0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-clist-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-clist
hs-libraries:         HSdata-clist-0.2-3h05bg3ef6q4JSfIXYvR3C
depends:              base-4.16.4.0 deepseq-1.4.6.1
haddock-interfaces:   /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html:         /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-clist-0.2-71-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-clist
version:              0.2
visibility:           public
id:                   data-clist-0.2-E35Tj0eB9anCAxV8LXQJnX
key:                  data-clist-0.2-E35Tj0eB9anCAxV8LXQJnX
license:              BSD-3-Clause
maintainer:
    Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>

author:               John Van Enk <vanenkj@gmail.com>
stability:            experimental
homepage:             https://github.com/sw17ch/data-clist
synopsis:             Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.

category:             Data Structures
abi:                  21476e3e700f211e3a26ae60328e1941
exposed:              True
exposed-modules:      Data.CircularList Data.CircularList.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-clist-0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-clist-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-clist
hs-libraries:         HSdata-clist-0.2-E35Tj0eB9anCAxV8LXQJnX
depends:              base-4.16.4.0 deepseq-1.4.6.1
haddock-interfaces:   /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html:         /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
